==> commonsdk-1.8.0-4509-20200513.021527-1-sources.jar: com/yy/mobile/replugin/ApiIpcBridge.java <==
package com.yy.mobile.replugin;

import android.util.Log;

import com.yy.mobile.ipc.IPCManager;
import com.yy.mobile.ipc.IpcApiSetting;

import com.unionyy.ipcapi.Hermes;
import com.unionyy.ipcapi.util.TypeUtils;

/**
 * Create by guananjie on 2020-02-26
 * E-mail: guananjie@yy.com
 * YY: 909042007
 */
public class ApiIpcBridge {
    public static <T> T registerIpc(Class<T> clazz) {
        try {
            if (IPCManager.instance != null) {
                IpcApiSetting setting = IPCManager.instance.getIpcApiSetting();
                if (setting == IpcApiSetting.Server && TypeUtils.getClassId(clazz) != null) {
                    T t = ImplUtil.getImpl(clazz);
                    Hermes.register(t.getClass());
                    Log.i("RepluginBridge", "register,ipc clazz:" + t.getClass());

                }
            }
        } catch (Exception e) {
            Log.e("RepluginBridge", "registerIpc", e);
        }
        return null;
    }

    public static <T> T getApi(Class<T> clazz) {
        if (IPCManager.instance != null) {
            try {
                IpcApiSetting setting = IPCManager.instance.getIpcApiSetting();
                    if (setting == IpcApiSetting.Clinet && TypeUtils.getClassId(clazz) != null && IPCManager.connectStatus) {
                        T temp = Hermes.newInstance(clazz);
                        if (temp != null) {
                            Log.i("RepluginBridge", "getIPCApi,clazz:" + clazz + " of instance is" + temp);
                            return temp;
                        }
                    }

            } catch (Exception e) {
                Log.e("RepluginBridge", "getApi", e);
            }
        }
        return null;
    }
}

==> commonsdk-1.19.0-6805-20201211.093908-1-sources.jar: com/yy/mobile/replugin/ApiIpcBridge.java <==
package com.yy.mobile.replugin;

import android.util.Log;
import com.yy.mobile.ipc.IPCManager;
import com.yy.mobile.ipc.IpcApiSetting;
import com.unionyy.ipcapi.Hermes;
import com.unionyy.ipcapi.util.TypeUtils;
import java.util.concurrent.ConcurrentHashMap;

/**
 * Create by guananjie on 2020-02-26
 * E-mail: guananjie@yy.com
 * YY: 909042007
 */
public class ApiIpcBridge {

    private static volatile boolean isFirstInit = true;

    public static <T> T registerIpc(Class<T> clazz) {
        try {
            if (IPCManager.instance != null) {
                IpcApiSetting setting = IPCManager.instance.getIpcApiSetting();
                if (setting == IpcApiSetting.Server) {
                    if (isFirstInit) {
                        isFirstInit = false;
                        ConcurrentHashMap map = ImplUtil.getClassMap();
                        for (Object key : map.keySet()) {
                            Class tempClass = (Class<T>) key;
                            Log.i("RepluginBridge", "tempClass = " + tempClass);
                            realRegister(tempClass);
                        }
                    } else {
                        realRegister(clazz);
                    }
                }
            }
        } catch (Exception e) {
            Log.e("RepluginBridge", "registerIpc", e);
        }
        return null;
    }

    private static <T> void realRegister(Class<T> clazz) {
        if (TypeUtils.getClassId(clazz) != null) {
            T t = ImplUtil.getImpl(clazz);
            Hermes.register(t.getClass());
            Log.i("RepluginBridge", "register,ipc clazz:" + t.getClass());
        }
    }

    public static <T> T getApi(Class<T> clazz) {
        if (IPCManager.instance != null) {
            try {
                IpcApiSetting setting = IPCManager.instance.getIpcApiSetting();
                    if (setting == IpcApiSetting.Clinet && TypeUtils.getClassId(clazz) != null && IPCManager.connectStatus) {
                        T temp = Hermes.newInstance(clazz);
                        if (temp != null) {
                            Log.i("RepluginBridge", "getIPCApi,clazz:" + clazz + " of instance is" + temp);
                            return temp;
                        }
                    }

            } catch (Exception e) {
                Log.e("RepluginBridge", "getApi", e);
            }
        }
        return null;
    }
}
